@@ -1,5 +1,5 @@
 package Mail::DMARC::Base;
-our $VERSION = '1.20150228'; # VERSION
+our $VERSION = '1.20150310'; # VERSION
 use strict;
 use warnings;
 
@@ -245,7 +245,7 @@ sub is_valid_ip {
 sub is_valid_domain {
     my ( $self, $domain ) = @_;
     return 0 if $domain !~ /^$RE{net}{domain}{-rfc1101}{-nospace}$/x;
-    my $tld = ( split /\./, $domain )[-1];
+    my $tld = ( split /\./, lc $domain )[-1];
     return 1 if $self->is_public_suffix($tld);
     $tld = join( '.', ( split /\./, $domain )[ -2, -1 ] );
     return 1 if $self->is_public_suffix($tld);
@@ -292,7 +292,7 @@ Mail::DMARC::Base - DMARC utility functions
 
 =head1 VERSION
 
-version 1.20150228
+version 1.20150310
 
 =head1 METHODS
 
